/* leakfinder_test - test harness for the leakfinder package
**
** Copyright (C) 2022 by Jef Poskanzer <jef@mail.acme.com>.
** All rights reserved.
**
** You may use this software however you like as long as you keep my
** name on it and don't sue me.
**
** For commentary on this license please see http://acme.com/license.html
*/

#include <stdlib.h>
#include <string.h>

#include "leakfinder.h"

int
main( int argc, char** argv )
    {
    int* ints;
    float* floats;
    char* str;

    ints = MALLOC( 10 * sizeof(int) );
    ints = REALLOC( ints, 20 * sizeof(int) );
    FREE( ints );

    floats = CALLOC( 10, sizeof(float) );
    FREE( floats );

    str = STRDUP( "test" );
    FREE( str );

    exit( 0 );
    }
